==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/GridColumnGroupOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnGroupOptionsDescription } from "./GridColumnGroupOptionsDescription";
/**
 * @hidden
 */
export let GridColumnGroupOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnGroupOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnGroupOptionsDescriptionMetadata.a == null) {
                GridColumnGroupOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnGroupOptionsDescriptionMetadata.c(GridColumnGroupOptionsDescriptionMetadata.a);
            }
            if (a.k(GridColumnGroupOptionsDescriptionMetadata.a)) {
                return;
            }
            a.ab(GridColumnGroupOptionsDescriptionMetadata.a);
        }
        static c(a) {
            GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            GridColumnGroupOptionsDescriptionMetadata.b(a);
            a.ad("GridColumnGroupOptions", () => new GridColumnGroupOptionsDescription());
            a.ac("GridColumnGroupOptions", GridColumnGroupOptionsDescriptionMetadata.a);
        }
    }
    GridColumnGroupOptionsDescriptionMetadata.$t = markType(GridColumnGroupOptionsDescriptionMetadata, 'GridColumnGroupOptionsDescriptionMetadata');
    GridColumnGroupOptionsDescriptionMetadata.a = null;
    return GridColumnGroupOptionsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/GridColumnGroupOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnGroupOptionsDescription } from "./GridColumnGroupOptionsDescription";
/**
 * @hidden
 */
export let GridColumnGroupOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnGroupOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnGroupOptionsDescriptionMetadata.a == null) {
                GridColumnGroupOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnGroupOptionsDescriptionMetadata.c(GridColumnGroupOptionsDescriptionMetadata.a);
            }
            if (a.k(GridColumnGroupOptionsDescriptionMetadata.a)) {
                return;
            }
            a.ac(GridColumnGroupOptionsDescriptionMetadata.a);
        }
        static c(a) {
            GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            GridColumnGroupOptionsDescriptionMetadata.b(a);
            a.ae("GridColumnGroupOptions", () => new GridColumnGroupOptionsDescription());
            a.ad("GridColumnGroupOptions", GridColumnGroupOptionsDescriptionMetadata.a);
        }
    }
    GridColumnGroupOptionsDescriptionMetadata.$t = markType(GridColumnGroupOptionsDescriptionMetadata, 'GridColumnGroupOptionsDescriptionMetadata');
    GridColumnGroupOptionsDescriptionMetadata.a = null;
    return GridColumnGroupOptionsDescriptionMetadata;
})();
